getnseg

Function getnseg 

pub unsafe fn getnseg(n: c_int) -> *mut segment_t
Get pointer to segment by its number. \deprecated Use get_segment_info_by_num() for safer access. \warning Obsoleted because it can slow down the debugger (it has to refresh the whole memory segmentation to calculate the correct answer) \param n segment number in the range (0..get_segm_qty()-1) \return nullptr or pointer to segment structure